@@ -15,24 +15,28 @@
 #ifndef __GIVARO_integer_H
 #define __GIVARO_integer_H
 
+#include "givaro-config.h"
+#include "gmp++/gmp++.h"
 #include "givaro/givbasictype.h"
 #include "givaro/givinit.h"
 #include "givaro/giverror.h"
-#include "givaro-config.h"
-#include "gmp++/gmp++.h"
+#include "givaro/givranditer.h"
+#include "givaro/random-integer.h"
+#include "givaro/ring-interface.h"
 #include <string>
 
 namespace Givaro {
 	//------------------------------------ Class IntegerDom
 	//! Integer Domain.
-	class IntegerDom {
+	class IntegerDom : public RingInterface<Integer> {
 	public:
+        using Self_t = IntegerDom;
 		typedef Integer Rep;
 		typedef Rep Element;
 
 
-		IntegerDom() : one(1UL), mOne(-1L), zero(0UL) {}
-		IntegerDom(const IntegerDom&) : one(1UL), mOne(-1L), zero(0UL) {}
+		IntegerDom() : one(1), mOne(-1), zero(0U) {}
+		IntegerDom(const IntegerDom&) : one(1), mOne(-1), zero(0U) {}
 
 		int operator==( const IntegerDom&) const
 		{
@@ -48,6 +52,9 @@ namespace Givaro {
 		const Integer mOne;
 		const Integer zero;
 
+        Integer characteristic() const { return zero; }
+        Integer& characteristic(Integer& p) const { return p = zero; }
+
 		// -- assignement
 		Rep& init  ( Rep& a ) const
 		{
@@ -57,19 +64,19 @@ namespace Givaro {
 		{
 			return a = b ;
 		}
-		Rep& read( Rep& a, const long i) const
+		Rep& read( Rep& a, const int64_t i) const
 		{
 			return a = Integer(i) ;
 		}
-		Rep& read( Rep& a, const unsigned long i) const
+		Rep& read( Rep& a, const uint64_t i) const
 		{
 			return a = Integer(i) ;
 		}
-		Rep& read( Rep& a, const int i) const
+		Rep& read( Rep& a, const int32_t i) const
 		{
 			return a = Integer(i) ;
 		}
-		Rep& read( Rep& a, const unsigned int i) const
+		Rep& read( Rep& a, const uint32_t i) const
 		{
 			return a = Integer(i) ;
 		}
@@ -91,7 +98,7 @@ namespace Givaro {
 
 		template<class XXX> XXX& convert(XXX& x, const Rep& a) const
 		{
-			return x=(XXX)a;
+			return Caster<XXX,Rep>(x,a);
 		}
 
 		// -- arithmetic operators
@@ -189,6 +196,11 @@ namespace Givaro {
 		{
 			return ::Givaro::gcd(g, a, b);
 		}
+		Rep& gcdin( Rep& g, const Rep& a) const
+		{
+            Rep tmp(g);
+			return ::Givaro::gcd(g, tmp, a);
+		}
 		Rep& lcm( Rep& l, const Rep& a, const Rep& b ) const
 		{
 			return ::Givaro::lcm(l, a, b);
@@ -208,21 +220,21 @@ namespace Givaro {
 
 
 		// - return n^l
-		Rep& pow(Rep& r, const Rep& n, const long l) const
+		Rep& pow(Rep& r, const Rep& n, const int64_t l) const
 		{
 			return r = ::Givaro::pow(n, l);
 		}
-		Rep& pow(Rep& r, const Rep& n, const unsigned long l) const
+		Rep& pow(Rep& r, const Rep& n, const uint64_t l) const
 		{
 			return r = ::Givaro::pow(n, l);
 		}
-		Rep& pow(Rep& r, const Rep& n, const int l) const
+		Rep& pow(Rep& r, const Rep& n, const int32_t l) const
 		{
-			return r = ::Givaro::pow(n, (long)l);
+			return r = ::Givaro::pow(n, (int64_t)l);
 		}
-		Rep& pow(Rep& r, const Rep& n, const unsigned int l) const
+		Rep& pow(Rep& r, const Rep& n, const uint32_t l) const
 		{
-			return r = ::Givaro::pow(n, (unsigned long)l);
+			return r = ::Givaro::pow(n, (uint64_t)l);
 		}
 
 		// - return square root of n
@@ -235,13 +247,13 @@ namespace Givaro {
 			return ::Givaro::sqrtrem(s,n, r);
 		}
 		// - base p logarithm of a
-		long logp(const Rep& a, const Rep& p) const
+		int64_t logp(const Rep& a, const Rep& p) const
 		{
 			return ::Givaro::logp(a,p);
 		}
 
 		// - return n^e % m
-		Rep& powmod(Rep& r, const Rep& n, const long e, const Rep& m) const
+		Rep& powmod(Rep& r, const Rep& n, const int64_t e, const Rep& m) const
 		{
 			return r = ::Givaro::powmod(n, e, m);
 		}
@@ -251,7 +263,7 @@ namespace Givaro {
 		}
 
 		// - Misc
-		unsigned long length (const Rep& a) const
+		uint64_t length (const Rep& a) const
 		{
 			return ::Givaro::length(a);
 		}
@@ -267,61 +279,91 @@ namespace Givaro {
 		{
 			return ::Givaro::isOne(a);
 		}
+		bool isMOne  (const Rep& a) const
+		{
+			return ::Givaro::isMOne(a);
+		}
+		/// isUnit
+		inline  bool isUnit (const Rep& x) const
+		{
+			return ::Givaro::isOne(x) || ::Givaro::isMOne(x);
+		}
+
+		/** @brief isDivisor (a, b)
+		 *  Test if b | a.
+		 */
+		inline  bool isDivisor (const Element& a, const Element& b) const
+		{
+			Element r; return ::Givaro::isZero(mod(r,a,b));
+		}
+
+        Element& abs(Element& x, const Element& a) const {
+            return x=::Givaro::abs(a);
+        }
+
+        int32_t compare(const Rep& a, const Rep& b) const {
+            return ::Givaro::compare(a,b);
+        }
+                
 		bool areEqual (const Rep& a, const Rep& b) const
 		{
-			return compare(a,b) ==0;
+			return ::Givaro::compare(a,b) ==0;
 		}
 		bool areNEqual(const Rep& a, const Rep& b) const
 		{
-			return compare(a,b) !=0;
+			return ::Givaro::compare(a,b) !=0;
+		}
+		bool areAssociates(const Element &x, const Element &y) const 
+		{
+			return ::Givaro::abs(x) == ::Givaro::abs(y);
 		}
 		bool isgeq(const Rep& a, const Rep& b) const
 		{
-			return compare(a,b) >= 0;
+			return ::Givaro::compare(a,b) >= 0;
 		}
 		bool isleq(const Rep& a, const Rep& b) const
 		{
-			return compare(a,b) <= 0;
+			return ::Givaro::compare(a,b) <= 0;
 		}
-		bool isgeq(const long b,const Rep& a ) const
+		bool isgeq(const int64_t b,const Rep& a ) const
 		{
-			return isgeq(Rep(b),a);
+			return this->isgeq(Rep(b),a);
 		}
-		bool isleq(const long b,const Rep& a ) const
+		bool isleq(const int64_t b,const Rep& a ) const
 		{
-			return isleq(Rep(b),a);
+			return this->isleq(Rep(b),a);
 		}
-		bool isgeq(const Rep& a, const long b) const
+		bool isgeq(const Rep& a, const int64_t b) const
 		{
-			return isgeq(a,Rep(b));
+			return this->isgeq(a,Rep(b));
 		}
-		bool isleq(const Rep& a, const long b) const
+		bool isleq(const Rep& a, const int64_t b) const
 		{
-			return isleq(a,Rep(b));
+			return this->isleq(a,Rep(b));
 		}
 		bool isgt(const Rep& a, const Rep& b) const
 		{
-			return compare(a,b) > 0;
+			return ::Givaro::compare(a,b) > 0;
 		}
 		bool islt(const Rep& a, const Rep& b) const
 		{
-			return compare(a,b) < 0;
+			return ::Givaro::compare(a,b) < 0;
 		}
-		bool isgt(const long b,const Rep& a ) const
+		bool isgt(const int64_t b,const Rep& a ) const
 		{
-			return isgt(Rep(b),a);
+			return this->isgt(Rep(b),a);
 		}
-		bool islt(const long b,const Rep& a ) const
+		bool islt(const int64_t b,const Rep& a ) const
 		{
-			return islt(Rep(b),a);
+			return this->islt(Rep(b),a);
 		}
-		bool isgt(const Rep& a, const long b) const
+		bool isgt(const Rep& a, const int64_t b) const
 		{
-			return isgt(a,Rep(b));
+			return this->isgt(a,Rep(b));
 		}
-		bool islt(const Rep& a, const long b) const
+		bool islt(const Rep& a, const int64_t b) const
 		{
-			return islt(a,Rep(b));
+			return this->islt(a,Rep(b));
 		}
 
 
@@ -330,19 +372,24 @@ namespace Givaro {
 		{ Integer::seeding(s) ;
 		}
 #endif
-		template< class RandIter > Rep& random(RandIter&, Rep& r, long s = 1) const
+
+        typedef RandomIntegerIterator<false,false> RandIter;
+        typedef GeneralRingNonZeroRandIter<Self_t> NonZeroRandIter;
+
+
+		template< class MyRandIter > Rep& random(MyRandIter&, Rep& r, long s = 1) const
 		{
 			return Integer::random(r,s);
 		}
-		template< class RandIter > Rep& random(RandIter&, Rep& r, const Rep& b) const
+		template< class MyRandIter > Rep& random(MyRandIter&, Rep& r, const Rep& b) const
 		{
 			return Integer::random(r,b);
 		}
-		template< class RandIter > Rep& nonzerorandom(RandIter&, Rep& r, long s = 1) const
+		template< class MyRandIter > Rep& nonzerorandom(MyRandIter&, Rep& r, long s = 1) const
 		{
 			return Integer::nonzerorandom(r,s);
 		}
-		template< class RandIter > Rep& nonzerorandom (RandIter&,Rep& r, const Rep& b) const
+		template< class MyRandIter > Rep& nonzerorandom (MyRandIter&,Rep& r, const Rep& b) const
 		{
 			return Integer::nonzerorandom(r,b);
 		}
@@ -374,4 +421,4 @@ namespace Givaro {
 } // Givaro
 
 #endif //__GIVARO_integer_H
-// vim:sts=8:sw=8:ts=8:noet:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
+// vim:sts=4:sw=4:ts=4:noet:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
