@@ -4,7 +4,7 @@
 // Givaro is governed by the CeCILL-B license under French law
 // and abiding by the rules of distribution of free software.
 // see the COPYRIGHT file for more details.
-// Time-stamp: <06 Jun 06 14:48:16 Jean-Guillaume.Dumas@imag.fr>
+// Time-stamp: <03 Aug 15 11:40:49 Jean-Guillaume.Dumas@imag.fr>
 // =================================================================== //
 
 
@@ -21,10 +21,6 @@
 #ifndef __GIVARO_integers_prime_H
 #define __GIVARO_integers_prime_H
 
-#ifndef _GIVARO_ISPRIMETESTS_
-#define _GIVARO_ISPRIMETESTS_ 5
-#endif
-
 #include "givaro/givinteger.h"
 
 namespace Givaro {
@@ -57,6 +53,12 @@ namespace Givaro {
 #define BOUNDARY_isprime TABMAX
 #define BOUNDARY_2_isprime TABMAX2
 
+#define GIVARO_ISLT(a,b) ((a)<(b))
+#define GIVARO_ISLEQ(a,b) ((a)<=(b))
+#define GIVARO_ISGT(a,b) ((a)>(b))
+#define GIVARO_ISGEQ(a,b) ((a)>=(b))
+
+
 	// =================================================================== //
 	//! Primality tests
 	// =================================================================== //
@@ -72,9 +74,9 @@ namespace Givaro {
 			//             return ((n)<BOUNDARY_isprime ?  isprime_Tabule(n) :
 			//                     (n)<BOUNDARY_2_isprime ? isprime_Tabule2(n) :
 			//                     probab_prime(n));
-			long l;
-			return int (int(islt(n,BOUNDARY_isprime) ?  isprime_Tabule((int)convert(l,n)):
-					islt(n,BOUNDARY_2_isprime) ? isprime_Tabule2((int)convert(l,n)):
+			int64_t l;
+			return int32_t (int32_t(GIVARO_ISLT(n,BOUNDARY_isprime) ?  isprime_Tabule((int32_t)convert(l,n)):
+					GIVARO_ISLT(n,BOUNDARY_2_isprime) ? isprime_Tabule2((int32_t)convert(l,n)):
 					local_prime(n,r)));
 		}
 
@@ -82,14 +84,14 @@ namespace Givaro {
 		// else return is 0 and r is undefined
 		unsigned int isprimepower(Rep&, const Rep&) const ;
 
-		template<class RandIter>
-		unsigned int Miller(RandIter& g, const Rep& n=_GIVARO_ISPRIMETESTS_) const  ;
+		template<class MyRandIter>
+		unsigned int Miller(MyRandIter& g, const Rep& n=_GIVARO_ISPRIMETESTS_) const  ;
 
-		template<class RandIter>
-		Rep& test_Lehmann(RandIter& g, Rep&, const Rep& n=_GIVARO_ISPRIMETESTS_) const  ;
+		template<class MyRandIter>
+		Rep& test_Lehmann(MyRandIter& g, Rep&, const Rep& n=_GIVARO_ISPRIMETESTS_) const  ;
 
-		template<class RandIter>
-		int Lehmann(RandIter& g, const Rep& n=_GIVARO_ISPRIMETESTS_)  const ;
+		template<class MyRandIter>
+		int Lehmann(MyRandIter& g, const Rep& n=_GIVARO_ISPRIMETESTS_)  const ;
 
 		int isprime_Tabule(const int n) const ;
 		int isprime_Tabule2(const int n) const ;
@@ -103,7 +105,7 @@ namespace Givaro {
 		// Using Integer
 		int local_prime(const Rep& n, int r=_GIVARO_ISPRIMETESTS_) const
 		{
-			return probab_prime(n,r);
+                    return Protected::probab_prime(n,r);
 		}
 
 	private:
