@@ -6,7 +6,7 @@
 // and abiding by the rules of distribution of free software.
 // see the COPYRIGHT file for more details.
 // Authors: T. Gautier
-// $Id: givpoly1.h,v 1.3 2011-02-02 16:23:56 bboyer Exp $
+// $Id: givpoly1.h,v 1.3 2011-02-02 16:23:56 briceboyer Exp $
 // ==========================================================================
 /** @file givpoly1.h
  * @ingroup poly1
@@ -28,7 +28,7 @@ namespace Givaro {
 // -- Poly1Dom<Domain,StorageTag>:
 // --
 // ==========================================================================
-template<class Domain, class StorageTag> class Poly1Dom;
+template<class Domain, class StorageTag=Dense> class Poly1Dom;
 
 template<class Domain> class Poly1Dom<Domain,Dense>;
 template<class Domain> class Poly1Dom<Domain,Sparse>;
