@@ -6,7 +6,7 @@
 // and abiding by the rules of distribution of free software.
 // see the COPYRIGHT file for more details.
 // Authors: T. Gautier
-// $Id: givpoly1dense.h,v 1.29 2011-02-02 16:23:56 bboyer Exp $
+// $Id: givpoly1dense.h,v 1.29 2011-02-02 16:23:56 briceboyer Exp $
 // ==========================================================================
 /** @file givpoly1dense.h
  * @ingroup poly1
@@ -21,6 +21,7 @@
 #include "givaro/givindeter.h"
 #include "givaro/givinteger.h"
 #include "givaro/givrandom.h"
+#include "givaro/givindeter.h"
 
 #ifndef __GIV_STANDARD_VECTOR
 #include <vector>
@@ -50,6 +51,12 @@ namespace Givaro {
 		givvector(const Self_t& p, givWithCopy xxx) :
 			__GIV_STANDARD_VECTOR<T,A>(p)
 		{}
+
+        template <class InputIterator>
+        givvector(InputIterator first, InputIterator last) 
+                : __GIV_STANDARD_VECTOR<T,A>(first,last)
+        {}
+
 		Self_t& reallocate (size_t s)
 		{
 			this->resize(s);
@@ -121,6 +128,8 @@ namespace Givaro {
 		// -- Self_t
 		typedef          Poly1Dom<Domain,Dense>    Self_t;
 
+	
+
 		// -- The representation of a dense polynomial.
 		// assuming that we have correct operator, especially size, allocate
 		// , reallocate
@@ -131,6 +140,7 @@ namespace Givaro {
 		typedef          Storage_t                 Rep;
 		typedef          const Storage_t                 constRep;
 		typedef          Storage_t                 Element;
+       		typedef GIV_randIter< Self_t, Element> RandIter;
 
 		Poly1Dom ()
 		{}
@@ -224,8 +234,8 @@ namespace Givaro {
 		// -- Assignment p = q
 		Rep& assign( Rep& p, const Rep& q) const;
 
-		// -- Convert polynomials : F.assign(cste, p[0])
-		Type_t& convert(Type_t&, const Rep &) const;
+		// -- Polynomial to value : F.assign(cste, p[0])
+		Type_t& assign(Type_t&, const Rep &) const;
 
 		// -- Convert polynomials : F.convert(cste, p[0])
 		template<class XXX>
@@ -246,6 +256,7 @@ namespace Givaro {
 		}
 #endif
 		int isOne   ( const Rep& P ) const;
+		int isMOne   ( const Rep& P ) const;
 		int areEqual ( const Rep& P, const Rep& Q ) const;
 		int areNEqual( const Rep& P, const Rep& Q ) const;
 
@@ -314,12 +325,12 @@ namespace Givaro {
         Rep& stdmul( Rep& R, const Rep& P, const Rep& Q) const;
             // Forces first level of Karatsuba multiplication algorithm
         Rep& karamul( Rep& R, const Rep& P, const Rep& Q) const;
-        
+
 		// Compute truncated mul: only the coefficients inside
 		// the degree interval, included
 		Rep& mul( Rep&, const Rep&, const Rep&, const Degree&, const Degree&) const;
-        
-        
+
+
 		Rep& sqr   ( Rep& q, const Rep& a ) const;
 
 
@@ -389,7 +400,7 @@ namespace Givaro {
 
 		// -- misc
 		// -- W <-- P^n
-		Rep& pow( Rep& W, const Rep& P, long n) const;
+		Rep& pow( Rep& W, const Rep& P, uint64_t n) const;
 		// -- W <-- P^n [ U ]
 		Rep& powmod( Rep& W, const Rep& P, IntegerDom::Element pwr, const Rep& U) const;
 		template < class MyInt >
@@ -399,28 +410,27 @@ namespace Givaro {
 		}
 
 		// -- W <-- P(X^b)
-		Rep& power_compose( Rep& W, const Rep& P, long b) const;
+		Rep& power_compose( Rep& W, const Rep& P, uint64_t b) const;
 
 		// -- n th cyclotomic polynomial
-		Rep& cyclotomic( Rep& P, long n) const;
+		Rep& cyclotomic( Rep& P, uint64_t n) const;
 
 
 		// -- Random generators
 		// -- Random dense polynomial of degree 0
-		template< class RandIter > Rep& random(RandIter& g, Rep& r) const;
+		template< class RandomIterator > Rep& random(RandomIterator& g, Rep& r) const;
 		// -- Random dense polynomial of size s
-		template< class RandIter > Rep& random(RandIter& g, Rep& r, long s) const ;
+		template< class RandomIterator > Rep& random(RandomIterator& g, Rep& r, uint64_t s) const ;
 		// -- Random dense polynomial of degree d
-		template< class RandIter > Rep& random(RandIter& g, Rep& r, Degree s) const ;
+		template< class RandomIterator > Rep& random(RandomIterator& g, Rep& r, Degree s) const ;
 
-		Rep& random(GivRandom& g, Rep& r, Degree s) const ;
 		// -- Random dense polynomial with same size as b.
-		template< class RandIter > Rep& random(RandIter& g, Rep& r, const Rep& b) const;
+		template< class RandomIterator > Rep& random(RandomIterator& g, Rep& r, const Rep& b) const;
 
-		template< class RandIter > Rep& nonzerorandom(RandIter& g, Rep& r) const;
-		template< class RandIter > Rep& nonzerorandom(RandIter& g, Rep& r, long s) const;
-		template< class RandIter > Rep& nonzerorandom(RandIter& g, Rep& r, Degree s) const ;
-		template< class RandIter > Rep& nonzerorandom(RandIter& g, Rep& r, const Rep& b) const;
+		template< class RandomIterator > Rep& nonzerorandom(RandomIterator& g, Rep& r) const;
+		template< class RandomIterator > Rep& nonzerorandom(RandomIterator& g, Rep& r, uint64_t s) const;
+		template< class RandomIterator > Rep& nonzerorandom(RandomIterator& g, Rep& r, Degree s) const ;
+		template< class RandomIterator > Rep& nonzerorandom(RandomIterator& g, Rep& r, const Rep& b) const;
 
 		// -- Square free decomposition
 		/** Sqrfree decomposition.
