@@ -4,7 +4,7 @@
 // Givaro is governed by the CeCILL-B license under French law
 // and abiding by the rules of distribution of free software.
 // see the COPYRIGHT file for more details.
-// Time-stamp: <27 Jun 05 11:35:32 Jean-Guillaume.Dumas@imag.fr>
+// Time-stamp: <23 Oct 15 15:35:46 Jean-Guillaume.Dumas@imag.fr>
 // ================================================================= //
 
 /** @file givpoly1factor.h
@@ -30,29 +30,31 @@ namespace Givaro {
 	// template<class Domain, class StorageTag> class Poly1FactorDom {};
 
 	//! Poly1FactorDom
-	template<class Domain, class Tag, class RandIter = GivRandom>
+	template<class Domain, class Tag = Dense, class RandomIterator = GivRandom>
 	class Poly1FactorDom : public Poly1Dom<Domain,Tag> {
 	protected:
 		using               Poly1Dom<Domain,Tag>::_domain;
 		typedef typename Poly1Dom<Domain,Tag>::Rep    Rep;
-		mutable          RandIter                      _g;
+		mutable          RandomIterator                      _g;
 	public:
 		using                                                 Poly1Dom<Domain,Tag>::one;
 		using                                                Poly1Dom<Domain,Tag>::zero;
 		typedef typename Poly1Dom<Domain,Tag>::Element                          Element;
-		typedef          RandIter                                      random_generator;
-		typedef typename Signed_Trait<typename Domain::Element>::unsigned_type Residu_t;
+		typedef          RandomIterator                                      random_generator;
+            	typedef typename Domain::Residu_t Residu_t;
 		typedef typename Signed_Trait<typename Domain::Element>::signed_type   Element_t;
+		// using typename Poly1Dom<Domain,Tag>::Type_t; //used for assign (clang complains)
+		typedef typename Poly1Dom<Domain,Tag>::Type_t Type_t; //used for assign (clang complains)
 		// typedef typename Domain::Residu_t                                      Residu_t;
 
 		Poly1FactorDom () {}
 
 		//! @warning  there is a copy of the random Iterator ...
-		Poly1FactorDom (Domain& d, const Indeter& X = Indeter(), const RandIter& g = RandIter() ) :
+		Poly1FactorDom (Domain& d, const Indeter& X = Indeter(), const RandomIterator& g = RandomIterator() ) :
 		       	Poly1Dom<Domain,Tag> (d,X), _g(g)
 	       	{}
 
-		Poly1FactorDom (const Poly1Dom<Domain,Tag>& P, const RandIter& g = RandIter()) :
+		Poly1FactorDom (const Poly1Dom<Domain,Tag>& P, const RandomIterator& g = RandomIterator()) :
 			Poly1Dom<Domain,Tag> (P), _g(g)
 	       	{}
 
@@ -110,13 +112,13 @@ namespace Givaro {
 
 		template< template<class, class> class Container, template <class> class Alloc>
 		void CZfactor( Container< Rep, Alloc<Rep> > & Lf,
-			       Container< unsigned long, Alloc<unsigned long> > & Le,
+			       Container< uint64_t, Alloc<uint64_t> > & Le,
 			       const Rep& f,
 			       Residu_t MOD)  const ;
 
 		template< template<class, class> class Container, template <class> class Alloc>
 		void CZfactor( Container< Rep, Alloc<Rep> > & Lf,
-			       Container< unsigned long, Alloc<unsigned long> > & Le,
+			       Container< uint64_t, Alloc<uint64_t> > & Le,
 			       const Rep& f )  const {
 			CZfactor(Lf, Le, f,_domain.residu());
 		}
@@ -138,6 +140,18 @@ namespace Givaro {
 		}
 
 
+            template<class PolyCont>
+            PolyCont& factor (PolyCont& factors,
+                              std::vector<uint64_t>& exp,
+                              const Rep& P) {
+                    // JGD 02.03.2012 : to be refactored
+                    // at least without pointers ...
+                CZfactor(factors, exp, P); // Cantor-Zassenhaus factorization
+                return factors;
+            }
+
+
+
 		// ---------------------------------------------------------------
 		// Irreducibility test
 		// ---------------------------------------------------------------
