@@ -1,19 +1,23 @@
-#ifndef _GIV_CATEGORY_H_
-#define _GIV_CATEGORY_H_
 // ==========================================================================
 // $Source: /var/lib/cvs/Givaro/src/library/tools/givcategory.h,v $
-// Copyright(c)'94-97 by Givaro Team
-// see the copyright file.
+// Copyright(c)'1994-2009 by The Givaro group
+// This file is part of Givaro.
+// Givaro is governed by the CeCILL-B license under French law
+// and abiding by the rules of distribution of free software.
+// see the COPYRIGHT file for more details.
 // Authors: T. Gautier
-// $Id: givcategory.h,v 1.3 2005/06/29 12:17:52 jgdumas Exp $
+// $Id: givcategory.h,v 1.4 2009-09-17 14:28:23 jgdumas Exp $
 // ==========================================================================
 // Description:
 // - Definition of traits.
 // It's a beta-beta version
+#ifndef __GIVARO_category_H
+#define __GIVARO_category_H
 
+namespace Givaro {
 
 // -- nothing
-class Undefined{}; 
+class Undefined{};
 
 
 // ==========================================================================
@@ -41,14 +45,14 @@ struct IsNotEqual { enum {val = !IsEqual<A,B>::val }; };
 // -- Characteristic for representation of vector and matrix
 // --
 // Sporadic is a Dense but may have quite a few zero Elements
-// Therefore some algorithms might be specialized and might 
+// Therefore some algorithms might be specialized and might
 // take advantage of this.
-class Sporadic{}; 
-class Dense : public Sporadic {}; 
-class Sparse{}; 
-// class Diagonal{}; typedef Diagonal Diag; 
-// class Toeplitz{}; 
-// class Hensel{}; 
+class Sporadic{};
+class Dense : public Sporadic {};
+class Sparse{};
+// class Diagonal{}; typedef Diagonal Diag;
+// class Toeplitz{};
+// class Hensel{};
 
 template<class CLASS>
 struct Sparsity_Trait {
@@ -73,4 +77,6 @@ template<class T, class Tag>
 StructFormat<T,Tag> Formatted( const T& val, Tag xx )
 { return StructFormat<T,Tag>(val); }
 
+} // Givaro
+
 #endif
